==> gcc-14_14.3.0.orig.tar.gz: gcc-14.3.0/gcc/testsuite/gcc.target/riscv/rvv/autovec/vls/convert-11.c <==
/* { dg-do compile } */
/* { dg-options "-march=rv64gcv_zvfh_zvl4096b -mabi=lp64d -O3 -mrvv-max-lmul=m8 -fno-trapping-math -fdump-tree-optimized" } */

#include "def.h"

DEF_CONVERT (fncvt, float, int8_t, 4)
DEF_CONVERT (fncvt, float, int8_t, 16)
DEF_CONVERT (fncvt, float, int8_t, 32)
DEF_CONVERT (fncvt, float, int8_t, 64)
DEF_CONVERT (fncvt, float, int8_t, 128)
DEF_CONVERT (fncvt, float, int8_t, 256)
DEF_CONVERT (fncvt, float, int8_t, 512)
DEF_CONVERT (fncvt, float, int8_t, 1024)

DEF_CONVERT (fncvt, float, uint8_t, 4)
DEF_CONVERT (fncvt, float, uint8_t, 16)
DEF_CONVERT (fncvt, float, uint8_t, 32)
DEF_CONVERT (fncvt, float, uint8_t, 64)
DEF_CONVERT (fncvt, float, uint8_t, 128)
DEF_CONVERT (fncvt, float, uint8_t, 256)
DEF_CONVERT (fncvt, float, uint8_t, 512)
DEF_CONVERT (fncvt, float, uint8_t, 1024)

DEF_CONVERT (fncvt, double, int16_t, 4)
DEF_CONVERT (fncvt, double, int16_t, 16)
DEF_CONVERT (fncvt, double, int16_t, 32)
DEF_CONVERT (fncvt, double, int16_t, 64)
DEF_CONVERT (fncvt, double, int16_t, 128)
DEF_CONVERT (fncvt, double, int16_t, 256)
DEF_CONVERT (fncvt, double, int16_t, 512)

DEF_CONVERT (fncvt, double, uint16_t, 4)
DEF_CONVERT (fncvt, double, uint16_t, 16)
DEF_CONVERT (fncvt, double, uint16_t, 32)
DEF_CONVERT (fncvt, double, uint16_t, 64)
DEF_CONVERT (fncvt, double, uint16_t, 128)
DEF_CONVERT (fncvt, double, uint16_t, 256)
DEF_CONVERT (fncvt, double, uint16_t, 512)

/* { dg-final { scan-assembler-times {vfncvt\.rtz\.x\.f.w} 30 } } */
/* { dg-final { scan-assembler-times {vncvt\.x\.x\.w} 30 } } */
/* { dg-final { scan-assembler-not {csrr} } } */
/* { dg-final { scan-tree-dump-not "1,1" "optimized" } } */
/* { dg-final { scan-tree-dump-not "2,2" "optimized" } } */
/* { dg-final { scan-tree-dump-not "4,4" "optimized" } } */
/* { dg-final { scan-tree-dump-not "16,16" "optimized" } } */
/* { dg-final { scan-tree-dump-not "32,32" "optimized" } } */
/* { dg-final { scan-tree-dump-not "64,64" "optimized" } } */
/* { dg-final { scan-tree-dump-not "128,128" "optimized" } } */
/* { dg-final { scan-tree-dump-not "256,256" "optimized" } } */
/* { dg-final { scan-tree-dump-not "512,512" "optimized" } } */
/* { dg-final { scan-tree-dump-not "1024,1024" "optimized" } } */
/* { dg-final { scan-tree-dump-not "2048,2048" "optimized" } } */
/* { dg-final { scan-tree-dump-not "4096,4096" "optimized" } } */

==> gcc-15_15.2.0.orig.tar.gz: gcc-15.2.0/gcc/testsuite/gcc.target/riscv/rvv/autovec/vls/convert-11.c <==
/* { dg-do compile } */
/* { dg-options "-march=rv64gcv_zvfh_zvl4096b -mabi=lp64d -O3 -mrvv-max-lmul=m8 -fno-trapping-math -fdump-tree-optimized" } */

#include "def.h"

DEF_CONVERT (fncvt, float, int8_t, 4)
DEF_CONVERT (fncvt, float, int8_t, 16)
DEF_CONVERT (fncvt, float, int8_t, 32)
DEF_CONVERT (fncvt, float, int8_t, 64)
DEF_CONVERT (fncvt, float, int8_t, 128)
DEF_CONVERT (fncvt, float, int8_t, 256)
DEF_CONVERT (fncvt, float, int8_t, 512)
DEF_CONVERT (fncvt, float, int8_t, 1024)

DEF_CONVERT (fncvt, float, uint8_t, 4)
DEF_CONVERT (fncvt, float, uint8_t, 16)
DEF_CONVERT (fncvt, float, uint8_t, 32)
DEF_CONVERT (fncvt, float, uint8_t, 64)
DEF_CONVERT (fncvt, float, uint8_t, 128)
DEF_CONVERT (fncvt, float, uint8_t, 256)
DEF_CONVERT (fncvt, float, uint8_t, 512)
DEF_CONVERT (fncvt, float, uint8_t, 1024)

DEF_CONVERT (fncvt, double, int16_t, 4)
DEF_CONVERT (fncvt, double, int16_t, 16)
DEF_CONVERT (fncvt, double, int16_t, 32)
DEF_CONVERT (fncvt, double, int16_t, 64)
DEF_CONVERT (fncvt, double, int16_t, 128)
DEF_CONVERT (fncvt, double, int16_t, 256)
DEF_CONVERT (fncvt, double, int16_t, 512)

DEF_CONVERT (fncvt, double, uint16_t, 4)
DEF_CONVERT (fncvt, double, uint16_t, 16)
DEF_CONVERT (fncvt, double, uint16_t, 32)
DEF_CONVERT (fncvt, double, uint16_t, 64)
DEF_CONVERT (fncvt, double, uint16_t, 128)
DEF_CONVERT (fncvt, double, uint16_t, 256)
DEF_CONVERT (fncvt, double, uint16_t, 512)

/* { dg-final { scan-assembler-times {vfncvt\.rtz\.x\.f.w} 30 } } */
/* { dg-final { scan-assembler-times {vnsrl\.wi} 30 } } */
/* { dg-final { scan-assembler-not {csrr} } } */
/* { dg-final { scan-tree-dump-not "1,1" "optimized" } } */
/* { dg-final { scan-tree-dump-not "2,2" "optimized" } } */
/* { dg-final { scan-tree-dump-not "4,4" "optimized" } } */
/* { dg-final { scan-tree-dump-not "16,16" "optimized" } } */
/* { dg-final { scan-tree-dump-not "32,32" "optimized" } } */
/* { dg-final { scan-tree-dump-not "64,64" "optimized" } } */
/* { dg-final { scan-tree-dump-not "128,128" "optimized" } } */
/* { dg-final { scan-tree-dump-not "256,256" "optimized" } } */
/* { dg-final { scan-tree-dump-not "512,512" "optimized" } } */
/* { dg-final { scan-tree-dump-not "1024,1024" "optimized" } } */
/* { dg-final { scan-tree-dump-not "2048,2048" "optimized" } } */
/* { dg-final { scan-tree-dump-not "4096,4096" "optimized" } } */
